==> haskell-microlens-aeson-2.5.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microlens-aeson
version:              2.5.1
visibility:           public
id:                   microlens-aeson-2.5.1-BTs0Va2gDfDEbIlcWgSTRY
key:                  microlens-aeson-2.5.1-BTs0Va2gDfDEbIlcWgSTRY
license:              MIT
copyright:
    Copyright (C) 2012 Paul Wilson, (C) 2013 Edward A. Kmett, (C) 2015 Colin Woodbury

maintainer:           Colin Woodbury <colin@fosskers.ca>
author:               Colin Woodbury
homepage:             http://github.com/fosskers/microlens-aeson/
synopsis:             Law-abiding lenses for Aeson, using microlens
description:          Law-abiding lenses for Aeson, using microlens.
category:             Numeric
abi:                  615c555773e2c758d282581e2040101e
exposed:              True
exposed-modules:      Lens.Micro.Aeson
hidden-modules:       Lens.Micro.Aeson.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/microlens-aeson-2.5.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/microlens-aeson-2.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microlens-aeson
hs-libraries:         HSmicrolens-aeson-2.5.1-BTs0Va2gDfDEbIlcWgSTRY
depends:
    aeson-2.1.2.1-GnWfeeQpoVOBig4HoIDDG9
    attoparsec-0.14.4-10U3JVdOf0KJjxjEqAIrEh base-4.15.1.0
    bytestring-0.10.12.1 hashable-1.4.2.0-8EyZ5q0qf6V2oPuIX4Sz4t
    microlens-0.4.13.1-AoR6D5midYZB5ErWoiySs4
    scientific-0.3.7.0-AejKlNxs4tarEm4tm38IP text-1.2.5.0
    vector-0.13.0.0-DcAY6cFNWmp2QJjfa2GrVo

haddock-interfaces:
    /usr/share/doc/haskell-microlens-aeson/html/microlens-aeson.haddock

haddock-html:         /usr/share/doc/haskell-microlens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-aeson-2.5.1-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microlens-aeson
version:              2.5.1
visibility:           public
id:                   microlens-aeson-2.5.1-4pFUIKv2wZ061qT1F3av4c
key:                  microlens-aeson-2.5.1-4pFUIKv2wZ061qT1F3av4c
license:              MIT
copyright:
    Copyright (C) 2012 Paul Wilson, (C) 2013 Edward A. Kmett, (C) 2015 Colin Woodbury

maintainer:           Colin Woodbury <colin@fosskers.ca>
author:               Colin Woodbury
homepage:             http://github.com/fosskers/microlens-aeson/
synopsis:             Law-abiding lenses for Aeson, using microlens
description:          Law-abiding lenses for Aeson, using microlens.
category:             Numeric
abi:                  652dc5f4ba6e47dc1bce50b620945f5f
exposed:              True
exposed-modules:      Lens.Micro.Aeson
hidden-modules:       Lens.Micro.Aeson.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/microlens-aeson-2.5.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/microlens-aeson-2.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microlens-aeson
hs-libraries:         HSmicrolens-aeson-2.5.1-4pFUIKv2wZ061qT1F3av4c
depends:
    aeson-2.1.2.1-ACNZHhH4U2e67aZXZDgTOb
    attoparsec-0.14.4-IunVluIlg1j8NQqYaVddnF base-4.15.1.0
    bytestring-0.10.12.1 hashable-1.4.3.0-ESEjVh9IF6l3kXlrvIyche
    microlens-0.4.13.1-AoR6D5midYZB5ErWoiySs4
    scientific-0.3.7.0-7992hTQSngN1mZw90JzZGW text-1.2.5.0
    vector-0.13.0.0-HZxUYbi5cfB4SV8TkUpCM2

haddock-interfaces:
    /usr/share/doc/haskell-microlens-aeson/html/microlens-aeson.haddock

haddock-html:         /usr/share/doc/haskell-microlens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
